# Firefly.ai Python SDK
Firefly.ai python SDK 

## Documentation
https://firefly-python-sdk.readthedocs.io/en/latest/

### Example notebook: 
https://github.com/NeuralAlgorithms/firefly-python-sdk/blob/master/examples/SDK_example.ipynb
#### Example notebook using google colab:
https://colab.research.google.com/github/NeuralAlgorithms/firefly-python-sdk/blob/master/examples/SDK_example.ipynb
## Installation:

`pip install fireflyai`

## Usage:

```
import fireflyai as firefly

firefly.authenticate(USER, PASSWORD)


```


